@@ -21,7 +21,12 @@ class Error;
 class KSIEVE_EXPORT Lexer
 {
 public:
-    enum Options { IncludeComments = 0, IgnoreComments = 1, IncludeLineFeeds = 0, IgnoreLineFeeds = 2 };
+    enum Options {
+        IncludeComments = 0,
+        IgnoreComments = 1,
+        IncludeLineFeeds = 0,
+        IgnoreLineFeeds = 2
+    };
 
     Lexer(const char *scursor, const char *send, int options = 0);
     ~Lexer();
