@@ -5,6 +5,8 @@
 */
 
 #include "findaccountinfojobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "../abstractakonadiimapsettinginterface.h"
 #include "../sieveimappasswordprovider.h"
 #include "../util.h"
@@ -39,7 +41,7 @@ FindAccountInfoJobTest::FindAccountInfoJobTest(QObject *parent)
 void FindAccountInfoJobTest::shouldReturnEmptyInfo()
 {
     auto job = new KSieveCore::FindAccountInfoJob;
-    job->setIdentifier(QStringLiteral("dummy"));
+    job->setIdentifier(u"dummy"_s);
     job->setProvider({});
     QSignalSpy spy(job, &KSieveCore::FindAccountInfoJob::findAccountInfoFinished);
     job->start();
@@ -62,30 +64,30 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QStringLiteral("foo.bla.com");
-        data1.userName = QStringLiteral("kde");
+        data1.imapServer = u"foo.bla.com"_s;
+        data1.userName = u"kde"_s;
         data1.sievePort = 543;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("SAFETY");
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"SAFETY"_s;
         data1.alternateAuthentication = -1;
         // MailTransport::Transport::EnumAuthenticationType::CRAM_MD5 = 2
         data1.authentication = 2;
         data1.sieveAlternateUrl = QString();
-        data1.password = QStringLiteral("password1");
+        data1.password = u"password1"_s;
         data1.sieveCustomPassword = QString();
 
         KSieveCore::Util::AccountInfo info1;
-        const QString password = QStringLiteral("password1");
-        const QString userName = QStringLiteral("kde");
+        const QString password = u"password1"_s;
+        const QString userName = u"kde"_s;
         const int port = 543;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://foo.bla.com?x-mech=CRAM-MD5"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://foo.bla.com?x-mech=CRAM-MD5"_s);
         info1.sieveUrl.setPassword(password);
         info1.sieveUrl.setUserName(userName);
         info1.sieveUrl.setPort(port);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
@@ -102,30 +104,30 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QStringLiteral("foo.bla.com");
-        data1.userName = QStringLiteral("kde");
+        data1.imapServer = u"foo.bla.com"_s;
+        data1.userName = u"kde"_s;
         data1.sievePort = 3;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("SAFETY");
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"SAFETY"_s;
         data1.alternateAuthentication = -1;
         // MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 0;
         data1.sieveAlternateUrl = QString();
-        data1.password = QStringLiteral("password2");
+        data1.password = u"password2"_s;
         data1.sieveCustomPassword = QString();
 
         KSieveCore::Util::AccountInfo info1;
-        const QString password = QStringLiteral("password2");
-        const QString userName = QStringLiteral("kde");
+        const QString password = u"password2"_s;
+        const QString userName = u"kde"_s;
         const int port = 3;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://foo.bla.com/vacation.siv?x-mech=LOGIN"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://foo.bla.com/vacation.siv?x-mech=LOGIN"_s);
         info1.sieveUrl.setPassword(password);
         info1.sieveUrl.setUserName(userName);
         info1.sieveUrl.setPort(port);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
@@ -141,30 +143,30 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QStringLiteral("foo.bla.com");
-        data1.userName = QStringLiteral("kde");
+        data1.imapServer = u"foo.bla.com"_s;
+        data1.userName = u"kde"_s;
         data1.sievePort = 3;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("SSL");
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"SSL"_s;
         data1.alternateAuthentication = -1;
         // MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 0;
         data1.sieveAlternateUrl = QString();
-        data1.password = QStringLiteral("password2");
+        data1.password = u"password2"_s;
         data1.sieveCustomPassword = QString();
 
         KSieveCore::Util::AccountInfo info1;
-        const QString password = QStringLiteral("password2");
-        const QString userName = QStringLiteral("kde");
+        const QString password = u"password2"_s;
+        const QString userName = u"kde"_s;
         const int port = 3;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://foo.bla.com/vacation.siv?x-mech=LOGIN"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://foo.bla.com/vacation.siv?x-mech=LOGIN"_s);
         info1.sieveUrl.setPassword(password);
         info1.sieveUrl.setUserName(userName);
         info1.sieveUrl.setPort(port);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
@@ -181,30 +183,30 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QStringLiteral("foo.bla.com");
-        data1.userName = QStringLiteral("kde");
+        data1.imapServer = u"foo.bla.com"_s;
+        data1.userName = u"kde"_s;
         data1.sievePort = 3;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("STARTTLS");
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"STARTTLS"_s;
         data1.alternateAuthentication = -1;
         // MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 0;
         data1.sieveAlternateUrl = QString();
-        data1.password = QStringLiteral("password2");
+        data1.password = u"password2"_s;
         data1.sieveCustomPassword = QString();
 
         KSieveCore::Util::AccountInfo info1;
-        const QString password = QStringLiteral("password2");
-        const QString userName = QStringLiteral("kde");
+        const QString password = u"password2"_s;
+        const QString userName = u"kde"_s;
         const int port = 3;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://foo.bla.com/vacation.siv?x-mech=LOGIN"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://foo.bla.com/vacation.siv?x-mech=LOGIN"_s);
         info1.sieveUrl.setPassword(password);
         info1.sieveUrl.setUserName(userName);
         info1.sieveUrl.setPort(port);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(userName);
         info1.sieveImapAccountSettings.setPassword(password);
@@ -221,19 +223,19 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = false;
         data1.sieveReuseConfig = true;
-        data1.imapServer = QStringLiteral("foo.bla.com");
-        data1.userName = QStringLiteral("kde");
+        data1.imapServer = u"foo.bla.com"_s;
+        data1.userName = u"kde"_s;
         data1.sievePort = 3;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = QString();
         data1.sieveCustomAuthentification = QString();
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("SAFETY");
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"SAFETY"_s;
         data1.alternateAuthentication = -1;
         // MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 0;
         data1.sieveAlternateUrl = QString();
-        data1.password = QStringLiteral("password2");
+        data1.password = u"password2"_s;
         data1.sieveCustomPassword = QString();
 
         KSieveCore::Util::AccountInfo info1;
@@ -244,36 +246,36 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
     }
 
     {
-        const QString sievePasswd = QStringLiteral("password3");
-        const QString imapPasswd = QStringLiteral("password2");
-        const QString imapUser = QStringLiteral("kde");
-        const QString sieveUser = QStringLiteral("foo1");
+        const QString sievePasswd = u"password3"_s;
+        const QString imapPasswd = u"password2"_s;
+        const QString imapUser = u"kde"_s;
+        const QString sieveUser = u"foo1"_s;
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.imapServer = u"foo.bla.com"_s;
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("SAFETY");
+        data1.sieveCustomAuthentification = u"CustomUserPassword"_s;
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"SAFETY"_s;
         data1.alternateAuthentication = 4;
         // MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 3;
-        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
+        data1.sieveAlternateUrl = u"bla.bla.com"_s;
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
         KSieveCore::Util::AccountInfo info1;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://bla.bla.com/vacation.siv?x-mech=GSSAPI"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://bla.bla.com/vacation.siv?x-mech=GSSAPI"_s);
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -285,36 +287,36 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
         QTest::newRow("sievereusecustomconfig1") << data1 << info1 << true << true;
     }
     {
-        const QString sievePasswd = QStringLiteral("password3");
-        const QString imapPasswd = QStringLiteral("password2");
-        const QString imapUser = QStringLiteral("kde");
-        const QString sieveUser = QStringLiteral("foo1");
+        const QString sievePasswd = u"password3"_s;
+        const QString imapPasswd = u"password2"_s;
+        const QString imapUser = u"kde"_s;
+        const QString sieveUser = u"foo1"_s;
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.imapServer = u"foo.bla.com"_s;
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("SAFETY");
+        data1.sieveCustomAuthentification = u"CustomUserPassword"_s;
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"SAFETY"_s;
         data1.alternateAuthentication = 4;
         // MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 3;
-        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
+        data1.sieveAlternateUrl = u"bla.bla.com"_s;
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
         KSieveCore::Util::AccountInfo info1;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://bla.bla.com?x-mech=GSSAPI"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://bla.bla.com?x-mech=GSSAPI"_s);
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -327,36 +329,36 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
     }
 
     {
-        const QString sievePasswd = QStringLiteral("password3");
-        const QString imapPasswd = QStringLiteral("password2");
-        const QString imapUser = QStringLiteral("kde");
-        const QString sieveUser = QStringLiteral("foo1");
+        const QString sievePasswd = u"password3"_s;
+        const QString imapPasswd = u"password2"_s;
+        const QString imapUser = u"kde"_s;
+        const QString sieveUser = u"foo1"_s;
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.imapServer = u"foo.bla.com"_s;
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("SSL");
+        data1.sieveCustomAuthentification = u"CustomUserPassword"_s;
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"SSL"_s;
         data1.alternateAuthentication = 4;
         // MailTransport::Transport::EnumAuthenticationType::PLAIN = 0
         data1.authentication = 3;
-        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
+        data1.sieveAlternateUrl = u"bla.bla.com"_s;
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
         KSieveCore::Util::AccountInfo info1;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://bla.bla.com?x-mech=GSSAPI"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://bla.bla.com?x-mech=GSSAPI"_s);
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -369,36 +371,36 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
     }
 
     {
-        const QString sievePasswd = QStringLiteral("password3");
-        const QString imapPasswd = QStringLiteral("password2");
-        const QString imapUser = QStringLiteral("kde");
-        const QString sieveUser = QStringLiteral("foo1");
+        const QString sievePasswd = u"password3"_s;
+        const QString imapPasswd = u"password2"_s;
+        const QString imapUser = u"kde"_s;
+        const QString sieveUser = u"foo1"_s;
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.imapServer = u"foo.bla.com"_s;
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("STARTTLS");
+        data1.sieveCustomAuthentification = u"CustomUserPassword"_s;
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"STARTTLS"_s;
         data1.alternateAuthentication = 4;
         // MailTransport::Transport::EnumAuthenticationType::DigestMD5 = 3
         data1.authentication = 3;
-        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
+        data1.sieveAlternateUrl = u"bla.bla.com"_s;
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
         KSieveCore::Util::AccountInfo info1;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://bla.bla.com?x-mech=GSSAPI"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://bla.bla.com?x-mech=GSSAPI"_s);
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -411,36 +413,36 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
     }
 
     {
-        const QString sievePasswd = QStringLiteral("password3");
-        const QString imapPasswd = QStringLiteral("password2");
-        const QString imapUser = QStringLiteral("kde");
-        const QString sieveUser = QStringLiteral("foo1");
+        const QString sievePasswd = u"password3"_s;
+        const QString imapPasswd = u"password2"_s;
+        const QString imapUser = u"kde"_s;
+        const QString sieveUser = u"foo1"_s;
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.imapServer = u"foo.bla.com"_s;
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("STARTTLS");
+        data1.sieveCustomAuthentification = u"CustomUserPassword"_s;
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"STARTTLS"_s;
         data1.alternateAuthentication = 4;
         // MailTransport::Transport::EnumAuthenticationType::DigestMD5 = 3
         data1.authentication = 4;
-        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
+        data1.sieveAlternateUrl = u"bla.bla.com"_s;
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
         KSieveCore::Util::AccountInfo info1;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://bla.bla.com?x-mech=GSSAPI"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://bla.bla.com?x-mech=GSSAPI"_s);
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -452,36 +454,36 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
         QTest::newRow("sievereusecustomconfig1withoutvacationfileStarttls2") << data1 << info1 << true << false;
     }
     {
-        const QString sievePasswd = QStringLiteral("password3");
-        const QString imapPasswd = QStringLiteral("password2");
-        const QString imapUser = QStringLiteral("kde");
-        const QString sieveUser = QStringLiteral("foo1");
+        const QString sievePasswd = u"password3"_s;
+        const QString imapPasswd = u"password2"_s;
+        const QString imapUser = u"kde"_s;
+        const QString sieveUser = u"foo1"_s;
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = true;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.imapServer = u"foo.bla.com"_s;
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("STARTTLS");
+        data1.sieveCustomAuthentification = u"CustomUserPassword"_s;
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"STARTTLS"_s;
         data1.alternateAuthentication = 4;
         // MailTransport::Transport::EnumAuthenticationType::DigestMD5 = 3
         data1.authentication = 4;
-        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
+        data1.sieveAlternateUrl = u"bla.bla.com"_s;
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
         KSieveCore::Util::AccountInfo info1;
-        info1.sieveUrl = QUrl::fromUserInput(QStringLiteral("sieve://bla.bla.com?x-mech=GSSAPI"));
+        info1.sieveUrl = QUrl::fromUserInput(u"sieve://bla.bla.com?x-mech=GSSAPI"_s);
         info1.sieveUrl.setPassword(sievePasswd);
         info1.sieveUrl.setUserName(sieveUser);
         info1.sieveUrl.setPort(sievePort);
-        info1.sieveImapAccountSettings.setServerName(QStringLiteral("foo.bla.com"));
+        info1.sieveImapAccountSettings.setServerName(u"foo.bla.com"_s);
         info1.sieveImapAccountSettings.setPort(imapPort);
         info1.sieveImapAccountSettings.setUserName(imapUser);
         info1.sieveImapAccountSettings.setPassword(imapPasswd);
@@ -494,27 +496,27 @@ void FindAccountInfoJobTest::shouldAssignValue_data()
     }
 
     {
-        const QString sievePasswd = QStringLiteral("password3");
-        const QString imapPasswd = QStringLiteral("password2");
-        const QString imapUser = QStringLiteral("kde");
-        const QString sieveUser = QStringLiteral("foo1");
+        const QString sievePasswd = u"password3"_s;
+        const QString imapPasswd = u"password2"_s;
+        const QString imapUser = u"kde"_s;
+        const QString sieveUser = u"foo1"_s;
         const int sievePort = 3;
         const int imapPort = 53;
         AkonadiImapSettingInterfaceDataTest data1;
         data1.sieveSupport = false;
         data1.sieveReuseConfig = false;
-        data1.imapServer = QStringLiteral("foo.bla.com");
+        data1.imapServer = u"foo.bla.com"_s;
         data1.userName = imapUser;
         data1.sievePort = sievePort;
         data1.imapPort = imapPort;
         data1.sieveCustomUsername = sieveUser;
-        data1.sieveCustomAuthentification = QStringLiteral("CustomUserPassword");
-        data1.sieveVacationFilename = QStringLiteral("vacation.siv");
-        data1.safety = QStringLiteral("STARTTLS");
+        data1.sieveCustomAuthentification = u"CustomUserPassword"_s;
+        data1.sieveVacationFilename = u"vacation.siv"_s;
+        data1.safety = u"STARTTLS"_s;
         data1.alternateAuthentication = 4;
         // MailTransport::Transport::EnumAuthenticationType::PLAIN = 2
         data1.authentication = 2;
-        data1.sieveAlternateUrl = QStringLiteral("bla.bla.com");
+        data1.sieveAlternateUrl = u"bla.bla.com"_s;
         data1.password = imapPasswd;
         data1.sieveCustomPassword = sievePasswd;
 
@@ -536,7 +538,7 @@ void FindAccountInfoJobTest::shouldAssignValue()
     std::unique_ptr<DataImapPasswordProvider> provider(new DataImapPasswordProvider(&data));
 
     auto job = new KSieveCore::FindAccountInfoJob;
-    job->setIdentifier(QStringLiteral("foo"));
+    job->setIdentifier(u"foo"_s);
     job->setProvider(provider.get());
     job->setCustomImapSettingsInterface(interface.get());
     job->setWithVacationFileName(useVacationFile);
