@@ -4,6 +4,8 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionenvelope.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "autocreatescripts/autocreatescriptutil_p.h"
 
 #include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
@@ -21,7 +23,7 @@
 using namespace KSieveUi;
 
 SieveConditionEnvelope::SieveConditionEnvelope(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
-    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("envelope"), i18n("Envelope"), parent)
+    : SieveCondition(sieveGraphicalModeWidget, u"envelope"_s, i18n("Envelope"), parent)
 {
 }
 
@@ -67,28 +69,27 @@ QWidget *SieveConditionEnvelope::createParamWidget(QWidget *parent) const
 
 QString SieveConditionEnvelope::code(QWidget *w) const
 {
-    const SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+    const SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(u"matchtypecombobox"_s);
     bool isNegative = false;
     const QString matchTypeStr = selectMatchCombobox->code(isNegative);
 
-    const SelectAddressPartComboBox *selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
+    const SelectAddressPartComboBox *selectAddressPart = w->findChild<SelectAddressPartComboBox *>(u"addresspartcombobox"_s);
     const QString selectAddressPartStr = selectAddressPart->code();
 
-    const SelectHeaderTypeComboBox *selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
+    const SelectHeaderTypeComboBox *selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(u"headertypecombobox"_s);
     const QString selectHeaderTypeStr = selectHeaderType->code();
 
-    const AbstractRegexpEditorLineEdit *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
+    const AbstractRegexpEditorLineEdit *edit = w->findChild<AbstractRegexpEditorLineEdit *>(u"editaddress"_s);
     const QString addressStr = AutoCreateScriptUtil::createAddressList(edit->code().trimmed(), false);
-    return AutoCreateScriptUtil::negativeString(isNegative)
-        + QStringLiteral("envelope %1 %2 %3 %4").arg(selectAddressPartStr, matchTypeStr, selectHeaderTypeStr, addressStr)
+    return AutoCreateScriptUtil::negativeString(isNegative) + u"envelope %1 %2 %3 %4"_s.arg(selectAddressPartStr, matchTypeStr, selectHeaderTypeStr, addressStr)
         + AutoCreateScriptUtil::generateConditionComment(comment());
 }
 
 QStringList SieveConditionEnvelope::needRequires(QWidget *w) const
 {
-    const SelectAddressPartComboBox *selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
-    const SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
-    return QStringList() << QStringLiteral("envelope") << selectAddressPart->extraRequire() << selectMatchCombobox->needRequires();
+    const SelectAddressPartComboBox *selectAddressPart = w->findChild<SelectAddressPartComboBox *>(u"addresspartcombobox"_s);
+    const SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(u"matchtypecombobox"_s);
+    return QStringList() << u"envelope"_s << selectAddressPart->extraRequire() << selectMatchCombobox->needRequires();
 }
 
 bool SieveConditionEnvelope::needCheckIfServerHasCapability() const
@@ -98,7 +99,7 @@ bool SieveConditionEnvelope::needCheckIfServerHasCapability() const
 
 QString SieveConditionEnvelope::serverNeedsCapability() const
 {
-    return QStringLiteral("envelope");
+    return u"envelope"_s;
 }
 
 QString SieveConditionEnvelope::help() const
@@ -118,15 +119,15 @@ void SieveConditionEnvelope::setParamWidgetValue(QXmlStreamReader &element, QWid
             const QString tagValue = element.readElementText();
             if (indexTag == 0) {
                 QString err;
-                auto selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
+                auto selectAddressPart = w->findChild<SelectAddressPartComboBox *>(u"addresspartcombobox"_s);
                 selectAddressPart->setCode(AutoCreateScriptUtil::tagValue(tagValue), name(), err);
                 // all: is default sometime we don't add it.
                 if (!err.isEmpty()) {
-                    auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+                    auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(u"matchtypecombobox"_s);
                     selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(tagValue, notCondition), name(), error);
                 }
             } else if (indexTag == 1) {
-                auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+                auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(u"matchtypecombobox"_s);
                 selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(tagValue, notCondition), name(), error);
             } else {
                 tooManyArguments(tagName, indexTag, 2, error);
@@ -135,10 +136,10 @@ void SieveConditionEnvelope::setParamWidgetValue(QXmlStreamReader &element, QWid
             ++indexTag;
         } else if (tagName == QLatin1StringView("str")) {
             if (indexStr == 0) {
-                auto selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
+                auto selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(u"headertypecombobox"_s);
                 selectHeaderType->setCode(element.readElementText());
             } else if (indexStr == 1) {
-                auto edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
+                auto edit = w->findChild<AbstractRegexpEditorLineEdit *>(u"editaddress"_s);
                 edit->setCode(AutoCreateScriptUtil::quoteStr(element.readElementText()));
             } else {
                 tooManyArguments(tagName, indexStr, 2, error);
@@ -147,10 +148,10 @@ void SieveConditionEnvelope::setParamWidgetValue(QXmlStreamReader &element, QWid
             ++indexStr;
         } else if (tagName == QLatin1StringView("list")) {
             if (indexStr == 0) {
-                auto selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
+                auto selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(u"headertypecombobox"_s);
                 selectHeaderType->setCode(AutoCreateScriptUtil::listValueToStr(element));
             } else if (indexStr == 1) {
-                auto edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
+                auto edit = w->findChild<AbstractRegexpEditorLineEdit *>(u"editaddress"_s);
                 edit->setCode(AutoCreateScriptUtil::listValueToStr(element));
             }
             ++indexStr;
